==> open-xchange-admin-reseller_7.10.5.orig.tar.bz2: open-xchange-admin-reseller-7.10.5/com.openexchange.reseller.impl/src/com/openexchange/reseller/impl/osgi/ResellerServiceActivator.java <==
/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.reseller.impl.osgi;

import com.openexchange.database.DatabaseService;
import com.openexchange.groupware.delete.DeleteListener;
import com.openexchange.lock.LockService;
import com.openexchange.osgi.HousekeepingActivator;
import com.openexchange.reseller.ResellerService;
import com.openexchange.reseller.impl.CachingResellerService;
import com.openexchange.reseller.impl.ResellerServiceImpl;
import com.openexchange.reseller.impl.groupware.CacheInvalidationOnContextDelete;

/**
 * {@link ResellerServiceActivator}
 *
 * @author <a href="mailto:kevin.ruthmann@open-xchange.com">Kevin Ruthmann</a>
 * @since v7.8.3
 */
public class ResellerServiceActivator extends HousekeepingActivator {

    /**
     * Initializes a new {@link ResellerServiceActivator}.
     */
    public ResellerServiceActivator() {
        super();
    }

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class[] { DatabaseService.class };
    }

    @Override
    protected Class<?>[] getOptionalServices() {
        return new Class<?>[] { LockService.class };
    }

    @Override
    protected boolean stopOnServiceUnavailability() {
        return true;
    }

    @Override
    protected void startBundle() throws Exception {
        registerService(ResellerService.class, new CachingResellerService(this, new ResellerServiceImpl(getService(DatabaseService.class))));
        registerService(DeleteListener.class, new CacheInvalidationOnContextDelete(this));
    }
}

==> open-xchange-admin-reseller_7.10.6.orig.tar.bz2: open-xchange-admin-reseller-7.10.6/com.openexchange.reseller.impl/src/com/openexchange/reseller/impl/osgi/ResellerServiceActivator.java <==
/*
 * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.reseller.impl.osgi;

import com.openexchange.caching.CacheService;
import com.openexchange.database.DatabaseService;
import com.openexchange.groupware.delete.DeleteListener;
import com.openexchange.lock.LockService;
import com.openexchange.osgi.HousekeepingActivator;
import com.openexchange.reseller.ResellerService;
import com.openexchange.reseller.impl.CachingResellerService;
import com.openexchange.reseller.impl.ResellerServiceImpl;
import com.openexchange.reseller.impl.groupware.CacheInvalidationOnContextDelete;

/**
 * {@link ResellerServiceActivator}
 *
 * @author <a href="mailto:kevin.ruthmann@open-xchange.com">Kevin Ruthmann</a>
 * @since v7.8.3
 */
public class ResellerServiceActivator extends HousekeepingActivator {

    /**
     * Initializes a new {@link ResellerServiceActivator}.
     */
    public ResellerServiceActivator() {
        super();
    }

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class[] { DatabaseService.class, CacheService.class };
    }

    @Override
    protected Class<?>[] getOptionalServices() {
        return new Class<?>[] { LockService.class };
    }

    @Override
    protected boolean stopOnServiceUnavailability() {
        return true;
    }

    @Override
    protected void startBundle() throws Exception {
        registerService(ResellerService.class, new CachingResellerService(this, new ResellerServiceImpl(getService(DatabaseService.class))));
        registerService(DeleteListener.class, new CacheInvalidationOnContextDelete(this));
    }
}
